==> ruby-vtk_0.1.1.orig.tar.gz: ruby-vtk-0.1.1.orig/Parallel/Parallel.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkParallelInstantiator(void);
extern SWIGEXPORT(void) Init_vtkBranchExtentTranslator(void);
extern SWIGEXPORT(void) Init_vtkCollectPolyData(void);
extern SWIGEXPORT(void) Init_vtkCommunicator(void);
extern SWIGEXPORT(void) Init_vtkCompositeManager(void);
extern SWIGEXPORT(void) Init_vtkCompositer(void);
extern SWIGEXPORT(void) Init_vtkCompressCompositer(void);
extern SWIGEXPORT(void) Init_vtkCutMaterial(void);
extern SWIGEXPORT(void) Init_vtkExtractPolyDataPiece(void);
extern SWIGEXPORT(void) Init_vtkExtractUnstructuredGridPiece(void);
extern SWIGEXPORT(void) Init_vtkInputPort(void);
extern SWIGEXPORT(void) Init_vtkMemoryLimitImageDataStreamer(void);
extern SWIGEXPORT(void) Init_vtkMultiProcessController(void);
extern SWIGEXPORT(void) Init_vtkOutputPort(void);
extern SWIGEXPORT(void) Init_vtkPCellDataToPointData(void);
extern SWIGEXPORT(void) Init_vtkPDataSetReader(void);
extern SWIGEXPORT(void) Init_vtkPDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkPImageWriter(void);
extern SWIGEXPORT(void) Init_vtkPLinearExtrusionFilter(void);
extern SWIGEXPORT(void) Init_vtkPOPReader(void);
extern SWIGEXPORT(void) Init_vtkPOutlineCornerFilter(void);
extern SWIGEXPORT(void) Init_vtkPOutlineFilter(void);
extern SWIGEXPORT(void) Init_vtkPPolyDataNormals(void);
extern SWIGEXPORT(void) Init_vtkPProbeFilter(void);
extern SWIGEXPORT(void) Init_vtkPSphereSource(void);
extern SWIGEXPORT(void) Init_vtkPStreamTracer(void);
extern SWIGEXPORT(void) Init_vtkPVGeometryFilter(void);
extern SWIGEXPORT(void) Init_vtkParallelFactory(void);
extern SWIGEXPORT(void) Init_vtkPassThroughFilter(void);
extern SWIGEXPORT(void) Init_vtkPieceScalars(void);
extern SWIGEXPORT(void) Init_vtkPipelineSize(void);
extern SWIGEXPORT(void) Init_vtkRTAnalyticSource(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridOutlineFilter(void);
extern SWIGEXPORT(void) Init_vtkSharedMemoryCommunicator(void);
extern SWIGEXPORT(void) Init_vtkSocketCommunicator(void);
extern SWIGEXPORT(void) Init_vtkSocketController(void);
extern SWIGEXPORT(void) Init_vtkThreadedController(void);
extern SWIGEXPORT(void) Init_vtkTransmitPolyDataPiece(void);
extern SWIGEXPORT(void) Init_vtkTransmitUnstructuredGridPiece(void);
extern SWIGEXPORT(void) Init_vtkTreeComposite(void);
extern SWIGEXPORT(void) Init_vtkTreeCompositer(void);
extern SWIGEXPORT(void) Init_vtkDummyController(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Parallel(void){

  Init_vtkParallelInstantiator();
  Init_vtkBranchExtentTranslator();
  Init_vtkCollectPolyData();
  Init_vtkCommunicator();
  Init_vtkCompositeManager();
  Init_vtkCompositer();
  Init_vtkCompressCompositer();
  Init_vtkCutMaterial();
  Init_vtkExtractPolyDataPiece();
  Init_vtkExtractUnstructuredGridPiece();
  Init_vtkInputPort();
  Init_vtkMemoryLimitImageDataStreamer();
  Init_vtkMultiProcessController();
  Init_vtkOutputPort();
  Init_vtkPCellDataToPointData();
  Init_vtkPDataSetReader();
  Init_vtkPDataSetWriter();
  Init_vtkPImageWriter();
  Init_vtkPLinearExtrusionFilter();
  Init_vtkPOPReader();
  Init_vtkPOutlineCornerFilter();
  Init_vtkPOutlineFilter();
  Init_vtkPPolyDataNormals();
  Init_vtkPProbeFilter();
  Init_vtkPSphereSource();
  Init_vtkPStreamTracer();
  Init_vtkPVGeometryFilter();
  Init_vtkParallelFactory();
  Init_vtkPassThroughFilter();
  Init_vtkPieceScalars();
  Init_vtkPipelineSize();
  Init_vtkRTAnalyticSource();
  Init_vtkRectilinearGridOutlineFilter();
  Init_vtkSharedMemoryCommunicator();
  Init_vtkSocketCommunicator();
  Init_vtkSocketController();
  Init_vtkThreadedController();
  Init_vtkTransmitPolyDataPiece();
  Init_vtkTransmitUnstructuredGridPiece();
  Init_vtkTreeComposite();
  Init_vtkTreeCompositer();
  Init_vtkDummyController();
}

==> ruby-vtk_0.2.0.orig.tar.gz: ruby-vtk-0.2.0.orig/Parallel/Parallel.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkParallelInstantiator(void);
extern SWIGEXPORT(void) Init_vtkBranchExtentTranslator(void);
extern SWIGEXPORT(void) Init_vtkCollectPolyData(void);
extern SWIGEXPORT(void) Init_vtkCommunicator(void);
extern SWIGEXPORT(void) Init_vtkCompositeManager(void);
extern SWIGEXPORT(void) Init_vtkCompositer(void);
extern SWIGEXPORT(void) Init_vtkCompressCompositer(void);
extern SWIGEXPORT(void) Init_vtkCutMaterial(void);
extern SWIGEXPORT(void) Init_vtkDuplicatePolyData(void);
extern SWIGEXPORT(void) Init_vtkExtractPolyDataPiece(void);
extern SWIGEXPORT(void) Init_vtkExtractUnstructuredGridPiece(void);
extern SWIGEXPORT(void) Init_vtkInputPort(void);
extern SWIGEXPORT(void) Init_vtkMemoryLimitImageDataStreamer(void);
extern SWIGEXPORT(void) Init_vtkMultiProcessController(void);
extern SWIGEXPORT(void) Init_vtkOutputPort(void);
extern SWIGEXPORT(void) Init_vtkPCellDataToPointData(void);
extern SWIGEXPORT(void) Init_vtkPDataSetReader(void);
extern SWIGEXPORT(void) Init_vtkPDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkPImageWriter(void);
extern SWIGEXPORT(void) Init_vtkPLinearExtrusionFilter(void);
extern SWIGEXPORT(void) Init_vtkPOPReader(void);
extern SWIGEXPORT(void) Init_vtkPOutlineCornerFilter(void);
extern SWIGEXPORT(void) Init_vtkPOutlineFilter(void);
extern SWIGEXPORT(void) Init_vtkPPolyDataNormals(void);
extern SWIGEXPORT(void) Init_vtkPProbeFilter(void);
extern SWIGEXPORT(void) Init_vtkPSphereSource(void);
extern SWIGEXPORT(void) Init_vtkPStreamTracer(void);
extern SWIGEXPORT(void) Init_vtkParallelFactory(void);
extern SWIGEXPORT(void) Init_vtkParallelRenderManager(void);
extern SWIGEXPORT(void) Init_vtkPassThroughFilter(void);
extern SWIGEXPORT(void) Init_vtkPieceScalars(void);
extern SWIGEXPORT(void) Init_vtkPipelineSize(void);
extern SWIGEXPORT(void) Init_vtkRTAnalyticSource(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridOutlineFilter(void);
extern SWIGEXPORT(void) Init_vtkSharedMemoryCommunicator(void);
extern SWIGEXPORT(void) Init_vtkSocketCommunicator(void);
extern SWIGEXPORT(void) Init_vtkSocketController(void);
extern SWIGEXPORT(void) Init_vtkThreadedController(void);
extern SWIGEXPORT(void) Init_vtkTransmitPolyDataPiece(void);
extern SWIGEXPORT(void) Init_vtkTransmitUnstructuredGridPiece(void);
extern SWIGEXPORT(void) Init_vtkTreeComposite(void);
extern SWIGEXPORT(void) Init_vtkTreeCompositer(void);
extern SWIGEXPORT(void) Init_vtkCompositeRenderManager(void);
extern SWIGEXPORT(void) Init_vtkDistributedStreamTracer(void);
extern SWIGEXPORT(void) Init_vtkDummyController(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Parallel(void){

  Init_vtkParallelInstantiator();
  Init_vtkBranchExtentTranslator();
  Init_vtkCollectPolyData();
  Init_vtkCommunicator();
  Init_vtkCompositeManager();
  Init_vtkCompositer();
  Init_vtkCompressCompositer();
  Init_vtkCutMaterial();
  Init_vtkDuplicatePolyData();
  Init_vtkExtractPolyDataPiece();
  Init_vtkExtractUnstructuredGridPiece();
  Init_vtkInputPort();
  Init_vtkMemoryLimitImageDataStreamer();
  Init_vtkMultiProcessController();
  Init_vtkOutputPort();
  Init_vtkPCellDataToPointData();
  Init_vtkPDataSetReader();
  Init_vtkPDataSetWriter();
  Init_vtkPImageWriter();
  Init_vtkPLinearExtrusionFilter();
  Init_vtkPOPReader();
  Init_vtkPOutlineCornerFilter();
  Init_vtkPOutlineFilter();
  Init_vtkPPolyDataNormals();
  Init_vtkPProbeFilter();
  Init_vtkPSphereSource();
  Init_vtkPStreamTracer();
  Init_vtkParallelFactory();
  Init_vtkParallelRenderManager();
  Init_vtkPassThroughFilter();
  Init_vtkPieceScalars();
  Init_vtkPipelineSize();
  Init_vtkRTAnalyticSource();
  Init_vtkRectilinearGridOutlineFilter();
  Init_vtkSharedMemoryCommunicator();
  Init_vtkSocketCommunicator();
  Init_vtkSocketController();
  Init_vtkThreadedController();
  Init_vtkTransmitPolyDataPiece();
  Init_vtkTransmitUnstructuredGridPiece();
  Init_vtkTreeComposite();
  Init_vtkTreeCompositer();
  Init_vtkCompositeRenderManager();
  Init_vtkDistributedStreamTracer();
  Init_vtkDummyController();
}
